import { describe, it, expect } from 'vitest'
import { build, createServer } from 'vite'

import vitePluginOxManifests from '../../dist/index'
import { getFileFromBundle, getPort } from '../util'

const __dirname = import.meta.dirname

describe('Simple manifest scenario', () => {
  it('works', async () => {
    const bundle = await build({
      root: __dirname,
      logLevel: 'silent',
      build: { write: false, rollupOptions: { input: {} } },
      plugins: [vitePluginOxManifests({

      })]
    })

    const manifestFile = getFileFromBundle('manifest', bundle)
    const manifests = JSON.parse(manifestFile.source)
    expect(Object.keys(manifests)).toHaveLength(1)
    expect(manifests['register.js'].meta.manifests[0].namespace).toBe('test')
  })

  it('works in dev mode', async () => {
    const server = await createServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginOxManifests({

      })]
    })
    const PORT = await getPort()
    await server.listen(PORT)

    const res = await fetch(`http://localhost:${PORT}/api/manifest.json`)
    const manifests = await res.json()
    await server.close()

    expect(Object.keys(manifests)).toHaveLength(1)
    expect(manifests[0].namespace).toBe('test')
    expect(manifests[0].path).toContain('register')
  })

  it('works in dev mode with base set', async () => {
    const server = await createServer({
      root: __dirname,
      base: '/appsuite/',
      logLevel: 'silent',
      plugins: [vitePluginOxManifests({

      })]
    })
    const PORT = await getPort()
    await server.listen(PORT)

    const res = await fetch(`http://localhost:${PORT}/appsuite/api/manifest.json`)
    const manifests = await res.json()
    await server.close()

    expect(Object.keys(manifests)).toHaveLength(1)
    expect(manifests[0].namespace).toBe('test')
    expect(manifests[0].path).toContain('register')
  })

  it('works in dev mode with base set (new endpoint)', async () => {
    const server = await createServer({
      root: __dirname,
      base: '/appsuite/',
      logLevel: 'silent',
      plugins: [vitePluginOxManifests({

      })]
    })
    const PORT = await getPort()
    await server.listen(PORT)

    const res = await fetch(`http://localhost:${PORT}/appsuite/manifests`)
    const manifests = await res.json()
    await server.close()

    expect(Object.keys(manifests)).toHaveLength(1)
    expect(manifests[0].namespace).toBe('test')
    expect(manifests[0].path).toContain('register')
  })

  it('does not empty files on transform', async () => {
    const server = await createServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginOxManifests({

      })]
    })
    const PORT = await getPort()
    await server.listen(PORT)

    const res = await fetch(`http://localhost:${PORT}/register.js`)
    expect(await res.text()).toContain("console.log('Hello world')\n")
    await server.close()
  })
})
