import { describe, it, expect } from 'vitest'
import { build } from 'vite'

import vitePluginOxManifests from '../../dist/index'
import { getFileFromBundle } from '../util'

const __dirname = import.meta.dirname

describe('Settings like in core, with requirements', () => {
  it('works', async () => {
    const bundle = await build({
      root: __dirname,
      logLevel: 'silent',
      build: {
        write: false,
        rollupOptions: {
          input: {},
          external: ['@/io.ox/core/settings']
        }
      },
      plugins: [vitePluginOxManifests({

      })]
    })
    const manifestFile = getFileFromBundle('manifest', bundle)
    const manifests = JSON.parse(manifestFile.source)
    expect(Object.keys(manifests)).toHaveLength(7)
    expect(manifests['settings.js'].meta.manifests[0].namespace).toBe('settings')
    expect(manifests['settings.js'].meta.manifests[0].requires).toBe('cap')
  })

  it('merges requirements for manifests', async () => {
    const bundle = await build({
      root: __dirname,
      logLevel: 'silent',
      build: {
        write: false,
        rollupOptions: {
          input: {},
          external: ['@/io.ox/core/settings']
        }
      },
      plugins: [vitePluginOxManifests({

      })]
    })

    const manifestFile = getFileFromBundle('manifest', bundle)
    const manifests = JSON.parse(manifestFile.source)
    expect(Object.keys(manifests)).toHaveLength(7)
    expect(manifests['other-settings.js'].meta.manifests[0].requires).toBeUndefined()
  })

  it('merges single requirement for manifests', async () => {
    const bundle = await build({
      root: __dirname,
      logLevel: 'silent',
      build: {
        write: false,
        rollupOptions: {
          input: {},
          external: ['@/io.ox/core/settings']
        }
      },
      plugins: [vitePluginOxManifests({

      })]
    })

    const manifestFile = getFileFromBundle('manifest', bundle)
    const manifests = JSON.parse(manifestFile.source)
    expect(Object.keys(manifests)).toHaveLength(7)
    expect(manifests['third-settings.js'].meta.manifests[0].requires).toBeUndefined()
  })

  it('merges multiple requirement for manifests', async () => {
    const bundle = await build({
      root: __dirname,
      logLevel: 'silent',
      build: {
        write: false,
        rollupOptions: {
          input: {},
          external: ['@/io.ox/core/settings']
        }
      },
      plugins: [vitePluginOxManifests({

      })]
    })

    const manifestFile = getFileFromBundle('manifest', bundle)
    const manifests = JSON.parse(manifestFile.source)
    expect(Object.keys(manifests)).toHaveLength(7)
    expect(manifests['forth-settings.js'].meta.manifests[0].requires).toBe('((capa && capb) || capc)||cap')
  })
})
