import { describe, it, expect } from 'vitest'
import { deepMergeObject } from '../../dist/util'

describe('Deep merge', () => {
  it('with objects', () => {
    expect(deepMergeObject({
      a: {
        b: 1
      }
    }, {
      a: {
        c: 2
      },
      d: 3
    })).toEqual({
      a: {
        b: 1,
        c: 2
      },
      d: 3
    })
  })

  it('with arrays', () => {
    expect(deepMergeObject({
      a: [1, 2, 3]
    }, {
      a: [4, 5, 6]
    })).toEqual({
      a: [1, 2, 3, 4, 5, 6]
    })
  })

  it('with strings', () => {
    expect(deepMergeObject({
      a: '1'
    }, {
      a: '2'
    })).toEqual({
      a: '2'
    })
  })

  it('with different types - arrays / object', () => {
    expect(() => deepMergeObject({
      a: []
    }, {
      a: {}
    })).toThrow()
  })

  it('with different types - object / string', () => {
    expect(() => deepMergeObject({
      a: {}
    }, {
      a: ''
    })).toThrow()
  })
})
