import { createServer } from 'vite'
import { describe, it, expect, afterEach } from 'vitest'
import vitePluginProxy from '../../dist/index'
import { createTestServer, getPort, http2Request, updateRequestManager } from '../util'

const __dirname = import.meta.dirname
process.noDeprecation = true

describe('http proxy', () => {
  afterEach(async () => {
    updateRequestManager()
  })

  it.skip('works', async () => {
    const server = await createTestServer()
    server.get('/api/test', (req, res) => {
      res.send({ hello: 'world' })
    })
    const SERVER_PORT = await getPort()
    await server.listen({ port: SERVER_PORT })

    const PROXY_PORT = await getPort()
    const server1 = await createServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        proxy: {
          '/api': {
            target: `http://localhost:${SERVER_PORT}`
          }
        },
        httpProxy: {
          target: 'http://localhost',
          port: PROXY_PORT
        }
      })]
    })
    const PORT = await getPort()
    await server1.listen(PORT)

    const { data } = await http2Request(`http://localhost:${PORT}/api/test`)
    expect(data).toEqual({ hello: 'world' })

    const { data: proxiedData } = await http2Request(`http://localhost:${PROXY_PORT}/api/test`)
    expect(proxiedData).toEqual({ hello: 'world' })

    await server1.close()
    await server.close()
  })
})
